/************************************************************************************
 *  Launchpad demprogram: dco_16mhz
 *
 * A program LED1-et s LED2-t villogtatja, 1/100-os kitltssel, kb. 10 s-os 
 * peridussal. MCLK-nak s SMCLK-nak kb. 16 MHz-es DCO frekvenvit lltunk be,
 * ACLK forrst pedig VLO/8-ra lltjuk (kb. 1500 Hz). 
 * ACLK =  VLO/8; MCLK = SMCLK = DCO (16 MHz)
 *
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *  - Vegyk le a TxD s RxD tktseket!
 *  - Felttelezzk, hogy a 32 kHz-es kvarc nincs beforrasztva! Ha mgis be lenne 
 *    forrasztva, akkor a P2 portra vonatkoz belltsokat hagyjuk ki a programbl!
 *
 *                MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |
 *          --|RST          XOUT|-
 *            |                 |
 *     LED1<--|P1.0         P1.6|-->LED2
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  May 2012
 *  IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 ************************************************************************************/
#include "io430.h"

void main(void) {
  WDTCTL = WDTPW + WDTHOLD;                 // Letiltjuk a watchdog idztt
  BCSCTL3 = LFXT1S_2;                       // ACLK forrsa legyen VLO (LFXT1Sx: '10')
  IFG1 &= ~OFIFG;                           // Az "oszcilltor hiba" jelzbit trlse
  //Mrsek szerint az albbi belltssal nlam 16.3 MHz lett DCO frekvencija
  //A gyrtsi szrstl fggen elfordulhat, hogy a DCOx = 4 (azaz DCOCTL = DCO2;)
  //bellts is elegend a 16 MHz-es frekvencia elrshez.  
  DCOCTL = DCO2 | DCO0;                     // DCOx = 5; MODx = 0; 
  BCSCTL1 = XT2OFF+RSEL3+RSEL2+RSEL0;       // RSELx = 13 (lsd slaz061b p3.)
  BCSCTL1 |= DIVA_3 + RSEL1;                // ACLK osztja: 8 s RSELx = 15
  BCSCTL2 = SELM_0 +                        // MCLK forrsa: DCO
            DIVM_0 +                        // MLCK osztja: 1
            DIVS_0;                         // SMCLK osztja: 1
// SELS_0 nincs definilva, de nulla lvn nem okoz gondot, hogy kihagytuk.
// a SELS = 0 bellts egybknt azt jelenti, hogy SMCLK forrsa DCO legyen    
  P1DIR = 0xFF;                             // Minden P1.x legyen kimenet
  P1OUT = 0;                                // Minden P1.x alacsony llapotba
  P2SEL = 0;                                // P2.x legyen digitlis I/O
  P2SEL2 = 0;
  P2DIR = 0xFF;                             // Minden P2.x legyen kimenet
  P2OUT = 0;                                // Minden P2.x alacsony llapotba

  while(1) {
    P1OUT |= BIT6 + BIT0;                   // LED1 s LED2 bekapcsolsa
    __delay_cycles(1600000);                // kb. 100 ms vrakozs
    P1OUT &= ~(BIT6 + BIT0);                // LED1 s LED2 lekapcsolsa
    __delay_cycles(160000000);              // kb. 10s vrakozs
  }
}
