/*****************************************************************************
 *  Launchpad demprogram: dco_1mhz
 *
 * A program LED2-t villogtatja, 1/100-os kitltssel, kb. 10 s-os peridussal.
 * Az 1 MHz-es, gyrilag kalibrlt  DCO frekvenvit hasznljuk.
 * A kis fogyaszts rdekben ACLK forrst VLO/8-ra lltjuk. 
 * ACLK =  VLO/8; MCLK = SMCLK = DCO (1 MHz)
 *
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *  - Vegyk le a TxD s RxD tktseket!
 *  - Felttelezzk, hogy a 32 kHz-es kvarc nincs beforrasztva! 
 *    Ha mgis be lenne forrasztva, akkor a P2 portra vonatkoz 
 *    belltsokat hagyjuk ki a programbl!
 *
 *                MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |
 *          --|RST          XOUT|-
 *            |                 |
 *     LED2<--|P1.6             |
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  May 2012
 *  IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 *****************************************************************************/
#include "io430.h"

void main(void) {
  WDTCTL = WDTPW + WDTHOLD;       // Letiltjuk a watchdog idztt
  BCSCTL3 = LFXT1S_2;             // ACLK forrsa legyen VLO (LFXT1Sx: '10')
  IFG1 &= ~OFIFG;                 // Az "oszcilltor hiba" jelzbit trlse
  DCOCTL = CALDCO_1MHZ;           // DCO belltsa a gyrilag kalibrlt 
  BCSCTL1 = CALBC1_1MHZ;          // 1 MHz-es frekvencira
  BCSCTL1 |= DIVA_3;              // ACLK osztja: 8
  BCSCTL2 = SELM_0 +              // MCLK forrsa: DCO
            DIVM_0 +              // MLCK osztja: 1
            DIVS_0;               // SMCLK osztja: 1
// SELS_0 nincs definilva, de nulla lvn nem okoz gondot, hogy kihagytuk.
// a SELS = 0 bellts egybknt azt jelenti, hogy SMCLK forrsa DCO legyen    
  P1DIR = 0xFF;                   // Minden P1.x legyen kimenet
  P1OUT = 0;                      // Minden P1.x alacsony llapotba
  P2SEL = 0;                      // P2.x legyen digitlis I/O
  P2SEL2 = 0;
  P2DIR = 0xFF;                   // Minden P2.x legyen kimenet
  P2OUT = 0;                      // Minden P2.x alacsony llapotba

  while(1) {
    P1OUT |= BIT6;                // P1.6 (LED2) bekapcsolsa
    __delay_cycles(100000);       // kb. 100 ms vrakozs
    P1OUT &= ~BIT6;               // P1.6 (LED2) lekapcsolsa
    __delay_cycles(10000000);     // kb. 10s vrakozs
  }
}
