/********************************************************************
 *  Launchpad demprogram: p1_3_change_state
 *
 * A programban az S2 nyomgombbal keltett megszaktsokkal a fut 
 * program llapott minden gombnyomsnl lptetjk. A fut program 
 * s az interrupt kiszolgl eljrs kztti kommunikcihoz egy 
 * 8 llapot jelzt hasznlunk. A fprogram minden ciklusban a jelz
 * ltal meghatrozott gon fut tovbb.
 *
 * MCLK s SMCLK rajele az alaprtelmezett 1 MHz-es DCO frekvencia,
 * ACLK-val nem foglalkozunk. 
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *  - Vegyk le a TxD s RxD tktseket!
 *  - Felttelezzk, hogy a 32 kHz-es kvarc nincs beforrasztva! 
 *    Ha mgis be lenne forrasztva, akkor a P2 portra vonatkoz 
 *    belltsokat hagyjuk ki a programbl!
 *
 *                MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |
 *          --|RST          XOUT|-
 *            |                 |
 *     LED1<--|P1.0         P1.3|<- S2 gomb
 *            |                 |
 *     LED2<--|P1.6             |
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  May 2012
 *  IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 ***************************************************************/

#include  "io430.h"

//--- Az interrupt szinten mdostott vltoz 'volatile' legyen! 
volatile int jelzo = 0;      // Jelz a fprogram irnytshoz

void main(void) {
  WDTCTL = WDTPW + WDTHOLD;  //Letiltjuk a watchdog idztt
//--- P1 PORT belltsa --------------------------------------------  
  P1DIR |= BIT0+BIT6;        //P1.0 s P1.6 legyen digitlis kimenet
  P1DIR &= ~BIT3;            //P1.3 legyen digitlis bemenet
//--- Az albbi kt utastssal bekapcsoljuk P1.3 bels felhzst  
  P1OUT |= BIT3;             //Felfel hzzuk, nem lefel  
  P1REN |= BIT3;             //Bels felhzs engedlyezse  
//-------------------------------------------------------------------
// P1.3 bemenet belltsa: interrupt minden lefut l berkezsekor
//-------------------------------------------------------------------  
  P1IES |= BIT3;             // P1.3 lefut lre rzkeny
  P1IFG &= ~BIT3;            // P1.3 IFG trlse
  P1IE  |= BIT3;             // P1.3 interrupt engedlyezse
//--- Programmegszakts engedlyezse s a f programhurok ---------  
  __enable_interrupt();      // A programmegszakts engedlyezse
  while(1) {
    switch(jelzo) { 
    case 0: 
      P1OUT &= ~BIT6;        // Kimenetek trlse
      P1OUT ^= BIT0;         // LED1 tkapcsolsa
    __delay_cycles(1000000); // Kb. 1000 ms vrakozs
    break;
    case 1: 
      P1OUT &= ~BIT6;        // Kimenetek trlse
      P1OUT ^= BIT0;         // LED1 tkapcsolsa
      __delay_cycles(500000);// Kb. 500 ms vrakozs
    break;
    case 2: 
      P1OUT &= ~BIT6;        // Kimenetek trlse
      P1OUT ^= BIT0;         // LED1 tkapcsolsa
      __delay_cycles(250000);// Kb. 250 ms vrakozs
    break;
    case 3: 
      P1OUT &= ~BIT6;        // Kimenetek trlse
      P1OUT ^= BIT0;         // LED1 tkapcsolsa
      __delay_cycles(125000);// Kb. 125 ms vrakozs
    break;
    case 4: 
      P1OUT &= ~BIT0;        // Kimenetek trlse
      P1OUT ^= BIT6;         // LED1 tkapcsolsa
    __delay_cycles(1000000); // Kb. 1000 ms vrakozs
    break;
    case 5: 
      P1OUT &= ~BIT0;        // Kimenetek trlse
      P1OUT ^= BIT6;         // LED1 tkapcsolsa
      __delay_cycles(500000);// Kb. 500 ms vrakozs
    break;
    case 6: 
      P1OUT &= ~BIT0;        // Kimenetek trlse
      P1OUT ^= BIT6;         // LED1 tkapcsolsa
      __delay_cycles(250000);// Kb. 250 ms vrakozs
    break;
    case 7: 
      P1OUT &= ~BIT0;        // Kimenetek trlse
      P1OUT ^= BIT6;         // LED1 tkapcsolsa
      __delay_cycles(125000);// Kb. 1000 ms vrakozs
    break; 
    }    
  }
}

//--- Port 1 programmegszakts kiszolglsa ------------------------
#pragma vector=PORT1_VECTOR
__interrupt void Port_1(void)
{
  jelzo++;                   // kvetkez llapotba vlt
  jelzo &= 0x07;             // jelzo nem lehet 7-nl nagyobb!  
  P1IFG &= ~BIT3;            // P1.3 interrupt jelzbit trlse
}

