/************************************************************************************
 *  Launchpad demprogram: p1_3_wakeup.c
 *
 * A programban az S2 nyomgombbal keltett megszaktsokkal a fprogramot 
 * felbresztjk. A program minden felbresztskor 2,5 msodpercig villogtatja
 * a LED-eket.
 * 
 * Indulskor s felbredskor MCLK s SMCLK rajele az alaprtelmezett 1 MHz-es DCO 
 * frekvencia ACLK-val nem foglalkozunk. Az inicializls/interupt kiszolgls utn,
 * vrakozs kzben a mikrovezrl LPM4-es energiatakarkos mdban van: a CPU s minden
 * rajel ki van kapcsolva. Ms nven ezt RAM tartalom megrz mdnak hvjk, 
 * a CPU felbresztse ilyenkor csak kls megszaktssal lehetsges.
 *
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *  - Vegyk le a TxD s RxD tktseket!
 *  - Felttelezzk, hogy a 32 kHz-es kvarc nincs beforrasztva! Ha mgis be lenne 
 *    forrasztva, akkor a P2 portra vonatkoz belltsokat hagyjuk ki a programbl!
 *
 *                MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |
 *          --|RST          XOUT|-
 *            |                 |
 *     LED1<--|P1.0         P1.3|- S2 gomb --- GND
 *            |                 |
 *     LED2<--|P1.6             |
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  May 2012
 *  Fejleszti krnyezet: IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 ************************************************************************************/

#include  "io430.h"

void main(void) {
  int i;
  
  WDTCTL = WDTPW + WDTHOLD;  // Letiltjuk a watchdog idztt
//--- P1 PORT belltsa -----------------------------------------------------  
  P1OUT = 0;                 // Minden P1.x alacsony llapotba
  P1DIR |= BIT0+BIT6;        //P1.0 s P1.6 legyen digitlis kimenet
  P1DIR &= ~BIT3;            //P1.3 legyen digitlis bemenet
//--- Az albbi kt utastssal bekapcsoljuk P1.3 bels felhzst  
  P1OUT |= BIT3;             //Felfel hzzuk, nem lefel  
  P1REN |= BIT3;             //Bels felhzs engedlyezse  
//----------------------------------------------------------------------------
// P1.3 bemenet belltsa: interrupt minden lefut l berkezsekor
//----------------------------------------------------------------------------  
//P1REN |= BIT3;             // P1.3 felhzst itt engedlyezhetnnk
  P1IES |= BIT3;             // P1.3 lefut lre rzkeny
  P1IFG &= ~BIT3;            // P1.3 IFG trlse
  P1IE |= BIT3;              // P1.3 interrupt engedlyezse
  while(1) {
    P1OUT |= BIT0;           // LED1 = 1
    P1OUT &= ~BIT6;          // LED2 = 0
    for(i=0; i<10; i++) {
      P1OUT ^= BIT0 + BIT6;  // LED1 s LED2 llapotnak tbillentse
      __delay_cycles(250000);// 250 ms vrakozs
    }
    P1OUT = ~(BIT0+BIT6);    // A LED-ek kikapcsolsa  
//--- Programmegszakts engedlyezse s belps LPM4 mdba -----------------  
    __low_power_mode_4();    // Alvs a kvetkez gombnyomsig
  }  
}

//--- Port 1 programmegszakts kiszolglsa ---------------------------------
#pragma vector=PORT1_VECTOR
__interrupt void Port_1(void) {
    P1IFG &= ~BIT3;            // P1.3 interrupt jelzbit trlse
  __low_power_mode_off_on_exit(); //Felbresztjk az alv CPU-t
}

