/************************************************************************
 *  Launchpad demprogram: pwm_cont
 *
 * Kt fggetlen PWM csatorna egyidej vezrlse. 
 * LED1 1 s peridussal villog, lland 1/60 kitltssel.
 * LED2 fnyereje fokozatosan ersdik, majd elhalvnyul. Peridusa ~3,4 s
 * A "llegz LED" algoritmusnak elzmnyei s forrsai:
 * 1. J. Martin: "Breathing LED effect with the LaunchPad!"
 * http://osx-launchpad.blogspot.com/2010_11_01_archive.html
 * 2. Rusty Haddock: demo-breathing-led (Part Deux) 
 * http://www.43oh.com/forum/viewtopic.php?f=9&p=4553#p4553
 *
 * A szmllt szabadonfut mdban (MCx=2) hasznljuk, rajele ACLK=12 kHz.
 * Timer_A szmlljnak tlcsordulskor nincs megszakts.
 *
 * Kt Capture/Compare csatorna regisztereit egymstl fggetlenl 
 * tltjk fel, s engedlyezzk, hogy programmegszaktst okozzanak,
 * amikor Timer_A szmllja az elre belltott TACCRx rtkkel 
 * megegyezik.
 *
 * zemmd bellts: mindkt csatornnl OUTMOD = 4 (Toggle).
 * A TIMER0_A0_VECTOR, illetve a TIMER0_A1_VECTOR nev megszaktsi vektorokhoz
 * rendelt kiszolgl eljrsokban a TACCR0/TACCR1 regisztereket felvltva 
 * a kitltssel, illetve a kitltst a peridusra kiegszt 
 * rats-szmmal kell megnvelni.
 *
 * ACLK = VLO (12 kHz); MCLK = SMCLK = DCO (1 MHz)
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *
 *                MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |
 *          --|RST          XOUT|-
 *            |                 |
 *     LED1<--|P1.0         P1.6|-->LED2
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  Oct 2011
 *  IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 ************************************************************************/
#include "io430.h"
#include "stdint.h"

uint16_t idx = 0;            // Index a kitltsi tnyezk szmtshoz
uint16_t next_sqr = 1;       // A kvetkez ngyzetszm 
uint16_t sqr_step = 3;       // j nvekmny a ngyzetszmok kiszmtshoz
uint16_t new_ccr1 = 2;       // A kitltsi tnyez
uint16_t the_rest = 118;     // A kikapcsolt llapot idtartama

int main(void) {
  WDTCTL = WDTPW|WDTHOLD;    // Letiltjuk a watchdog idztt
  BCSCTL1= CALBC1_1MHZ;      // A gyrilag kalibrlt 1 MHz 
  DCOCTL= CALDCO_1MHZ;       // DCO frekvencia belltsa
  BCSCTL3 |= LFXT1S_2;       // ACLK forrsa legyen VLO
  P1OUT = 0;                 // Kimenetek 0-rl indulnak
  P1DIR |= BIT0|BIT6;        // P1.0 s P1.6 kimenet legyen   
  P1SEL |= BIT6;             // P1.6 Timer_A TA1 kimenete legyen 
  TACCR0 = 12000;            // TACCR0 kivr 1 s-ot
  TACCR1 = 12000;            // TACCR1 kivr 1 s-ot
  TACTL = TASSEL_1 |         // Timer_A forrsa ACLK legyen
               MC_2|         // szabadonfut md
              TACLR;         // A szmllt indulskor trljk 
  TACCTL0 = OUTMOD_4|CCIE;   // Toggle md s megszakts
  TACCTL1 = OUTMOD_4|CCIE;   // Toggle md s megszakts
//--- A fprogram itt befejezi a tnykedst s aludni tr.
  __low_power_mode_3();      // LPM3 md: MCLK,SMCLK,DCO=ki, GIE=be
}

//--- TACCR0 megszakts kiszolglsa ---------------------------------
//--- TACCIFG0 automatikusan trldik! --------------------------------
#pragma vector=TIMER0_A0_VECTOR
__interrupt void ccr0_isr(void) {
  if(P1OUT_bit.P0) {
    P1OUT &= ~BIT0;          // LED1 kikapcsolsa
    TACCR0 += 11800;         // Ennyi ideig marad kikapcsolva 
  } else {
    P1OUT |= BIT0;           // LED1 bekapcsolsa
    TACCR0 += 200;           // Ennyi ideig marad bekapcsolva 
  }
}

//--- TACCR1 megszakts kiszolglsa ---------------------------------
//--- TACCIFG1-et neknk kell trlni! --------------------------------
#pragma vector=TIMER0_A1_VECTOR
__interrupt void ccr1_isr(void) {
  if(P1IN_bit.P6) {
    TACCR1 += new_ccr1;        // Belltjuk a kitltst 
    new_ccr1 = (next_sqr>>8)+2;// Az j kitltsi tnyez kiszmolsa
    the_rest = 120-new_ccr1;   // A kikapcsolt llapot idtartama
    idx++;                     // A fut index nvelse
    if (idx < 170) {           // Az els 170 lpsben felfel lpnk  
       next_sqr += sqr_step;
       sqr_step += 2;
    } else if (idx < 340) {    // A msodik 170 lpsben lefel lpnk
       sqr_step -= 2;
       next_sqr -= sqr_step;
    } else idx = 0;            // j peridus kezddik
  } else {
    TACCR1 += (the_rest);      // A kikapcsolt llapot ideje
  }
  TACCTL1 &= ~CCIFG;           // A megszaktsi jelzbit trlse
}

