/************************************************************************
 *  Launchpad demprogram: pwm_led
 *
 * A program LED2 fnyerejt folyamatosan vltoztatja, 
 * mintha a LED "llegezne". A program elzmnyei s forrsai:
 * 1. J. Martin: "Breathing LED effect with the LaunchPad!"
 * http://osx-launchpad.blogspot.com/2010_11_01_archive.html
 * 2. Rusty Haddock: demo-breathing-led (Part Deux) 
 * http://www.43oh.com/forum/viewtopic.php?f=9&p=4553#p4553
 * 
 * Timer rajele SMCLK = 1 MHz lesz. 100 Hz PWM frekvencit vlasztva
 * 10 000 impulzust kell leszmolni, teht TACCR0 = 9999 legyen.
 * A LED kb. 2 s-os flperidusa alatt 200 lpsben ngyzetesen nvekv 
 * kitltst adunk meg, a kvetkez 200 peridusban pedig cskken
 * kitltssel lpkednk vissza. Technikai okobl azonban 200 lps 
 * helyett csak 199-t hajtunk vgre, hogy a TACCR1 < TACCR0 felttel
 * mindig teljesljn. 
 *
 * Algoritmus: 
 * -----------
 * A kitltst Rusty Haddock programja alapjn a new_ccr1 = x^2/4 + 1 
 * kplettel szmoljuk ki. Szorzs s oszts helyett a ngyzetszmok 
 * sorozatt azonban a pratlam szmok felsszegzsvel lltjuk el, 
 * a nggyel trtn osztst pedig logikai eltolssal vgezzk el.
 *
 * zemmd bellts: OUTMOD = 7 (reset/set)
 * Megszakts forrsa: CCIFG1 
 *
 * ACLK =  n/a; MCLK = SMCLK = DCO (1 MHz)
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G22x3 mikrovezrlvel
 *
 *                MSP430G22x3
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |
 *          --|RST          XOUT|-
 *            |                 |
 *            |             P1.6|-->LED2
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  Oct 2011
 *  IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 ************************************************************************/
#include "io430.h"
#include "stdint.h"

uint16_t idx = 0;            // Index a kitltsi tnyezk szmtshoz
uint16_t next_sqr = 1;       // A kvetkez ngyzetszm 
uint16_t sqr_step = 3;       // j nvekmny a ngyzetszmok kiszmtshoz
uint16_t new_ccr1 = 1;       // A kitltsi tnyez

int main(void) {
  WDTCTL = WDTPW|WDTHOLD;    // Letiltjuk a watchdog idztt
  BCSCTL1= CALBC1_1MHZ;      // A gyrilag kalibrlt 1 MHz 
  DCOCTL= CALDCO_1MHZ;       // DCO frekvencia belltsa
  P1DIR |= BIT6;             // P1.6 (LED2) kimenet legyen   
  P1SEL |= BIT6;             // P1.6 Timer_A TA1 kimenete legyen 
  TACCR0 = 9999;             // PWM frekvencia = 1 MHz/10000 = 100 Hz
  TACCR1 = 0;                // TACCR1(= fnyessg) indul rtke
  TACTL = TASSEL_2 |         // Timer_A forrsa SMCLK legyen
               MC_1|         // Felfel szmlls TACCR0-ig 
              TACLR;         // A szmllt trljk 
  TACCTL1 = OUTMOD_7|        // Reset/set amikor TACCR1/TACCR0-hoz r
                CCIE;        // Megszakts, ha a szmlls TACCR1-hoz r
  __low_power_mode_0();      // LPM0 md: MCLK=ki, GIE=be
}

//--- TACCR1 megszakts kiszolglsa ---------------------------------
#pragma vector=TIMER0_A1_VECTOR
__interrupt void ta1_isr(void) {
  TACCTL1 &= ~CCIFG;         // A megszaktsi jelzbit trlse
  while(TAR <= new_ccr1);    // Vrunk, amg TAR nagyobb lesz, mint az j kitlts
  TACCR1 = new_ccr1;
  new_ccr1 = next_sqr>>2;    // Az j kitltsi tnyez
  idx++;                     // A fut index nvelse
  if (idx < 199) {           // Az els 195 lpsben felfel lpnk  
     next_sqr += sqr_step;
     sqr_step += 2;
  } else if (idx < 397) {    // A msodik 195 lpsben lefel lpnk
     sqr_step -= 2;
     next_sqr -= sqr_step; 
  } else idx = 0;            // A fel-le peridus vge, sipirc vissza!
}