/************************************************************************
 *  Launchpad demprogram: pwm_led2
 *
 * A program LED2 fnyerejt folyamatosan vltoztatja, 
 * mintha a LED "llegezne". A program elzmnyei s forrsai:
 * 1. J. Martin: "Breathing LED effect with the LaunchPad!"
 * http://osx-launchpad.blogspot.com/2010_11_01_archive.html
 * 2. Rusty Haddock: demo-breathing-led (Part Deux) 
 * http://www.43oh.com/forum/viewtopic.php?f=9&p=4553#p4553
 * 
 * Timer rajele ACLK = 12 kHz lesz. 100 Hz PWM frekvencit vlasztva
 * 120 impulzust kell leszmolni, teht TACCR0 = 199 legyen.
 * A LED kb. 2 s-os flperidusa alatt 200 lpsben ngyzetesen nvekv 
 * kitltst adunk meg, a kvetkez 200 peridusban pedig cskken
 * kitltssel lpkednk vissza. 
 *
 * Algoritmus: 
 * -----------
 * A kitltst Rusty Haddock programja alapjn a new_ccr1 = x^2/512 
 * kplettel szmoljuk ki, a ngyzetszmok sorozatt a pratlam szmok 
 * felsszegzsvel lltjuk el, az osztst pedig logikai eltolssal 
 * vgezzk el.
 *
 * zemmd bellts: OUTMOD = 7 (reset/set)
 * Megszakts forrsa: CCIFG1 
 *
 * ACLK = VLO; MCLK = SMCLK = DCO (1 MHz)
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *
 *                MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |
 *          --|RST          XOUT|-
 *            |                 |
 *            |             P1.6|-->LED2
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  May 2012
 *  IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 ************************************************************************/
#include "io430.h"
#include "stdint.h"

uint16_t idx = 0;            // Index a kitltsi tnyezk szmtshoz
uint16_t next_sqr = 1;       // A kvetkez ngyzetszm 
uint16_t sqr_step = 3;       // j nvekmny a ngyzetszmok kiszmtshoz
uint16_t new_ccr1 = 1;       // A kitltsi tnyez

int main(void) {
  WDTCTL = WDTPW|WDTHOLD;    // Letiltjuk a watchdog idztt
  BCSCTL1= CALBC1_1MHZ;      // A gyrilag kalibrlt 1 MHz 
  DCOCTL= CALDCO_1MHZ;       // DCO frekvencia belltsa
  BCSCTL3 |= LFXT1S_2;       // ACLK forrsa: VLO
  P1DIR |= BIT6;             // P1.6 (LED2) kimenet legyen   
  P1SEL |= BIT6;             // P1.6 Timer_A TA1 kimenete legyen 
  TACCR0 = 119;              // PWM frekvencia = 12 kHz/120 = 100 Hz
  TACCR1 = 0;                // TACCR1(= fnyessg) indul rtke
  TACTL = TASSEL_1 |         // Timer_A forrsa ACLK legyen
               MC_1|         // Felfel szmlls TACCR0-ig 
              TACLR;         // A szmllt trljk 
  TACCTL0 =     CCIE;        // Megszakts, ha a szmlls TACCR0-hoz r
  TACCTL1 = OUTMOD_7;        // Reset/set amikor TACCR1/TACCR0-hoz r

  __low_power_mode_3();      // LPM0 md: MCLK,SMCLK,DCO=ki, GIE=be
}

//--- TACCR0 megszakts kiszolglsa ---------------------------------
//--- CCIFG0 automatikusan trldik!
#pragma vector=TIMER0_A0_VECTOR
__interrupt void ccr0_isr(void) {
  TACCR1 = new_ccr1;         // Belltjuk a kitltst 
  new_ccr1 = (next_sqr>>9);  // Az j kitltsi tnyez
  if (idx < 200) {           // Az els 170 lpsben felfel lpnk  
     next_sqr += sqr_step;
     sqr_step += 2;
     idx++;                  // A fut index nvelse
  } else if (idx < 400) {    // A msodik 170 lpsben lefel lpnk
     sqr_step -= 2;
     next_sqr -= sqr_step;
     idx++;                  // A fut index nvelse     
  } else {
    idx = 0;                 // A fel-le peridus vge, sipirc vissza!
  }      
}