/************************************************************************************
 *  Launchpad demprogram: vlo_test
 *
 * A program LED1-et villogtatja, 1/100-os kitltssel, kb. 10 s-os peridussal.
 * A legalacsonyabb bellthat rajelet hasznljuk, a DCO s LFXT1 oszcilltorokat 
 * kikapcsoljuk. ACLK =  MCLK = SMCLK = VLO/8 (kb. 1500 Hz)
 *
 * Mintnak felhasznltuk az MSP430D2xx1 mintaprogram gyjtemny (slac463a.zip)
 * 1_VLO.c programjt (D. Dang, Texas Instruments, Oct. 2010)
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *  - Vegyk le a TxD s RxD tktseket!
 *  - Felttelezzk, hogy a 32 kHz-es kvarc nincs beforrasztva! Ha mgis be lenne 
 *    forrasztva, akkor a P2 portra vonatkoz belltsokat hagyjuk ki a programbl!
 *
 *                MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |
 *          --|RST          XOUT|-
 *            |                 |
 *     LED1<--|P1.0             |
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  May 2012
 *  Fejleszti krnyezet: IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 ************************************************************************************/
#include "io430.h"

void main(void) {
  WDTCTL = WDTPW + WDTHOLD;                 // Letiltjuk a watchdog idztt
  BCSCTL3 |= LFXT1S_2;                      // ACLK forrsa: LFXT1 helyett VLO
  IFG1 &= ~OFIFG;                           // Az "oszcilltor hiba" jelzbit trlse
  __bis_SR_register(SCG0);                  // DCO kikapcsolsa
  BCSCTL1 |= DIVA_3;                        // ACLK osztja: 8
  BCSCTL2 = SELM_3 +                        // MCLK forrsa: LFXT1/VLO
            DIVM_3 +                        // MLCK osztja: 8
            SELS   +                        // SCLK forrsa: LFXT1/VLO
            DIVS_3;                         // SMCLK osztja: 8
  P1DIR = 0xFF;                             // Minden P1.x legyen kimenet
  P1OUT = 0;                                // Minden P1.x alacsony llapotba
  P2SEL = 0;                                // P2.x legyen digitlis I/O
  P2SEL2 = 0;
  P2DIR = 0xFF;                             // Minden P2.x legyen kimenet
  P2OUT = 0;                                // Minden P2.x alacsony llapotba

  while(1) {
    P1OUT |= BIT0;                          // P1.0 (LED1) bekapcsolsa
    __delay_cycles(150);                    // kb. 100 ms vrakozs
    P1OUT &= ~BIT0;                         // P1.0 (LED1) lekapcsolsa
    __delay_cycles(15000);                  // Delay 10s
  }
}
