/********************************************************************
 *  Launchpad demprogram: wdt_interval
 *
 * A program LED1-et s LED2-t klnbz temben villogtatja.
 * Az idztshez a periodikus megszaktst generl  WDT 
 * szolgltat idalapot, kb. 52 ms peridussal. Az egyes 
 * feladatok egymstl eltr ksleltetseit az interrupt 
 * kiszolgl eljrsban, szoftveres szmllk segtsgvel 
 * oldottuk meg. Az idztett esemnyek szma knnyen bvthet.
 *
 * A vrakozs alatt a program LPM3 energitakarkos mdban alszik: 
 * MCLK, SMCLK s DCO kikapcsolva, csak ACLK jr, VLO forrsbl.
 *
 * 
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *
 *                MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 |  
 *          --|RST          XOUT|-
 *            |                 |
 *     LED1<--|P1.0         P1.6|-->LED2
 *
 * 
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  May 2012
 *  IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 *********************************************************************/
#include "io430.h"
#include "stdint.h"

volatile uint16_t delay1,delay2;

void main(void)
{
  WDTCTL = WDT_ADLY_16;               // WDT ~50 ms peridussal
  BCSCTL3 |= LFXT1S_2;                // ACLK = VLO (~12 kHz)
  IFG1 &= ~OFIFG;                     // Clear OSCFault flag
  BCSCTL2 |= SELM_3 + SELS;           // MCLK = SMCLK = VLO
  IE1 |= WDTIE;                       // WDT interrupt engedlyezse
//--- LED-ek s ksleltetsek belltsa --------------------------------  
  P1DIR |= BIT0+BIT6;                 // P1.0 P1.6 legyen kimenet
  P1OUT |= BIT0+BIT6;                 // P1.0 P1.6 kezdetben vilgt
  delay1 = 30;                        // LED1 peridusa ~3,1 s
  delay2 = 70;                        // LED1 peridusa ~7.3 s
  __low_power_mode_3();               // Interrupt s LPM3 engedlyezse 
}

//--- Watchdog Timer megszaktsnak kiszolglsa -----------------------
#pragma vector=WDT_VECTOR
__interrupt void watchdog_timer(void) { 
  if(--delay1==0) {                   // Szmlljuk a megszaktsokat
    P1OUT ^= BIT0;                    // P1.0 llapotnak tbillentse
    delay1 = 30;                      // Lejrt szmll jratltse
  } 
  if(--delay2==0) {
    P1OUT ^= BIT6;                    // P1.6 llapotnak tbillentse
    delay2 = 70;                      // Lejrt szmll jratltse
  }
}

