/*******************************************************************************
 *  MSP430G2553 Demo - Basic Clock rajelgenertor-rendszer belltsa , 
 *                     gyrilag kalibrlt DCO frekvencik belltsa,
 *                     a kalibrcis konstansok BCSCTL1 s DCOCTL-be 
 *                     tltsvel. Bufferelt rajel kimenetek bekapcsolsa.
 *  
 *  Lers: A bufferelt ACLK jel a P1.0 kimeneten jelenik meg, 
 *          az alaprtelmezett SMCLK jel (DCO) a P1.4 kiementen jelenik meg.
 *          Az MCLK jel nem vezethet ki hardveresen, de a P1.5 kimenet
 *          szoftveres vezrlsvel MCLK/10 frekvencij kimen jelet lltunk 
 *          el (10 utastsciklusba telik az tkapcsols s a visszaugrs).
 *
 *  Az MSP430G2553 mikrovezrlnl az 1, 8, 12 s 16 Mhz-es DCO frekvencihoz
 *  llnak rendelkezsre kalibrcis konstansok az INFOA memria terleten.
 *  A vlasztshoz a kvnt frekvencia belltst vegyk ki a megjegyzbl!
 *
 *  ACLK = LFXT1 = 32768, MCLK = SMCLK = vlaszthatan 1, 8, 12 or 16Mhz
 *
 * Hardver kvetelmnyek:
 *  - Launchpad MSP430G2553 mikrovezrlvel
 *  - Felttelezzk, hogy a 32 kHz-es kvarc be van forrasztva. Ha mgsem lenne 
 *    beforrasztva, akkor  a BCSCTL3 |= LFXT1S_2; utasts ell vegyk ki a
 *    megjegyzs jelt!
 *
 *               MSP430G2553
 *             -----------------
 *         /|\|              XIN|-
 *          | |                 | 32kHz
 *          --|RST          XOUT|-
 *            |                 |
 *            |       P1.4/SMCLK|-->SMCLK = DCO
 *            |             P1.5|-->MCLK/10 = DCO/10
 *            |        P1.0/ACLK|-->ACLK = 32kHz (vagy ~12 kHz)
 * 
 *  A program eredetijnek forrsa: MSP430G2xx3 Code Examples
 *  D. Dang
 *  Texas Instruments Inc.
 *  December 2010
 *
 *  Magyar vltozat:
 *  I. Cserny
 *  MTA ATOMKI, Debrecen
 *  May 2012
 *  IAR Embedded Workbench for MSP430 v5.30.1 Kickstart Edition
 ******************************************************************************/

#include "io430.h"

void main(void)
{
  WDTCTL = WDTPW + WDTHOLD;                 // Letiltjuk a watchdog idztt
  if (CALBC1_1MHZ ==0xFF || CALDCO_1MHZ == 0xFF) {  
    while(1);                               // Ha a kalibrcis konstansokat valaki
                                            // kitrlte, nem engedi tovbb a CPU-t!
  } 
 
//-- Ha nincs beforrasztva a 32 kHz-es kavrckristly, akkor vegyk ki 
//-- a megjegyzs jelet a kvetkez sor elejrl! Ekkor ACLK = VLO lesz 
//  BCSCTL3 |= LFXT1S_2;                      // ACLK forrsa: LFXT1 helyett VLO  

//-- Az albbiak kzl az rvnyesl, amelyiket kivesszk a megjegyzsbl.
  //1Mhz
  BCSCTL1 = CALBC1_1MHZ;                    // Tartomny belltsa
  DCOCTL = CALDCO_1MHZ;                     // DCO step s modulci belltsa*/

/* //8Mhz
  BCSCTL1 = CALBC1_8MHZ;                    // Tartomny belltsa
  DCOCTL = CALDCO_8MHZ;                     // DCO step s modulci belltsa*/

/* //12Mhz
  BCSCTL1 = CALBC1_12MHZ;                   // Tartomny belltsa
  DCOCTL = CALDCO_12MHZ;                    // DCO step s modulci belltsa*/

/* //16Mhz
  BCSCTL1 = CALBC1_16MHZ;                   // Tartomny belltsa
  DCOCTL = CALDCO_16MHZ;                    // DCO step s modulci belltsa*/

  P1DIR |= BIT0+BIT4+BIT5;                  // P1.0, P1.4 s P1.5 legyen kimenet
  P1SEL |= BIT0+BIT4;                       // P1.0, P1.4 ACLK, SMCLK kimenet
  P1SEL2 &= ~(BIT0+BIT4);                   // P1.0, P1.4 ACLK, SMCLK kimenet

  while(1) {
    P1OUT |= BIT5;    	                    // P1.1 = 1
    P1OUT &= ~BIT5;                         // P1.1 = 0
  }
}

